"""
android-asset-resizer

:copyright: (c) 2013 by Tristan Waddington.
:license: Apache 2.0, see LICENSE for more details.

"""

__version__ = '1.0.3'
__author__ = 'Tristan Waddington'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2013 Tristan Waddington'
